@@ -37,7 +37,7 @@ class backgrounds(TemplateFormat):
     convert = None
     prefix = None
     stretch = False
-    md5fn = "md5sum"
+    fallback_md5fn = "md5sum"
 
     def prepare(self):
         self.convert_cmd = getProgPath('/usr/bin/convert')
@@ -111,7 +111,11 @@ class backgrounds(TemplateFormat):
         else:
             workdir = nameFile
             prefix = ""
-        md5_fn = os.path.join(workdir, self.md5fn)
+        if prefix:
+            md5_fn = os.path.join(workdir, "%s.md5" %
+                                  re.sub("[-._]+$", "", prefix))
+        else:
+            md5_fn = os.path.join(workdir, self.fallback_md5fn)
         image_md5 = self.getImageMD5(source)
         if os.path.exists(md5_fn):
             md5sum = readFile(md5_fn).strip()
@@ -136,8 +140,8 @@ class backgrounds(TemplateFormat):
         else:
             removed_files = []
             extensions = self.objVar.Get('cl_image_formats')
-            re_remove = re.compile(r"^.*\d{3,4}x\d{3,4}\.(%s)$"
-                                   % "|".join(extensions))
+            re_remove = re.compile(r"^%s\d{3,4}x\d{3,4}\.(%s)$"
+                                   % (prefix, "|".join(extensions)))
             for remove_fn in listDirectory(workdir, fullPath=True):
                 fn = os.path.split(remove_fn)[1]
                 if re_remove.match(fn):
